@@ -13,7 +13,7 @@ use warnings;
 
 package Metabase::Index;
 BEGIN {
-  $Metabase::Index::VERSION = '0.007';
+  $Metabase::Index::VERSION = '0.008';
 }
 # ABSTRACT: Interface for Metabase indexing
 
@@ -38,7 +38,7 @@ sub clone_metadata {
     for my $key (keys %$data) {
       # I'm just starting with a strict-ish set.  We can tighten or loosen
       # parts of this later. -- rjbs, 2009-03-28
-      die "invalid metadata key" unless $key =~ /\A[-_a-z0-9.]+\z/;
+      die "invalid metadata key '$key'" unless $key =~ /\A[-_a-z0-9.]+\z/i;
       $metadata{ "$type.$key" } = $data->{$key};
     }
   }
@@ -63,7 +63,7 @@ Metabase::Index - Interface for Metabase indexing
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
